package com.ruoyi.manage.controller;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.manage.domain.BaseManufacturer;
import com.ruoyi.manage.service.IBaseManufacturerService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 轮挡厂家管理Controller
 * 
 * @author wangh
 * @date 2023-12-18
 */
@Controller
@RequestMapping("/manage/base_manufacturer")
public class BaseManufacturerController extends BaseController
{
    private String prefix = "manage/base_manufacturer";

    @Autowired
    private IBaseManufacturerService baseManufacturerService;

    @RequiresPermissions("manage:base_manufacturer:view")
    @GetMapping()
    public String base_manufacturer()
    {
        return prefix + "/base_manufacturer";
    }

    /**
     * 查询轮挡厂家管理列表
     */
    @RequiresPermissions("manage:base_manufacturer:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(BaseManufacturer baseManufacturer)
    {
        startPage();
        List<BaseManufacturer> list = baseManufacturerService.selectBaseManufacturerList(baseManufacturer);
        return getDataTable(list);
    }

    /**
     * 导出轮挡厂家管理列表
     */
    @RequiresPermissions("manage:base_manufacturer:export")
    @Log(title = "轮挡厂家管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(BaseManufacturer baseManufacturer)
    {
        List<BaseManufacturer> list = baseManufacturerService.selectBaseManufacturerList(baseManufacturer);
        ExcelUtil<BaseManufacturer> util = new ExcelUtil<BaseManufacturer>(BaseManufacturer.class);
        return util.exportExcel(list, "轮挡厂家管理数据");
    }

    /**
     * 新增轮挡厂家管理
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存轮挡厂家管理
     */
    @RequiresPermissions("manage:base_manufacturer:add")
    @Log(title = "轮挡厂家管理", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(BaseManufacturer baseManufacturer)
    {
        return toAjax(baseManufacturerService.insertBaseManufacturer(baseManufacturer));
    }

    /**
     * 修改轮挡厂家管理
     */
    @RequiresPermissions("manage:base_manufacturer:edit")
    @GetMapping("/edit/{manufacturerId}")
    public String edit(@PathVariable("manufacturerId") Long manufacturerId, ModelMap mmap)
    {
        BaseManufacturer baseManufacturer = baseManufacturerService.selectBaseManufacturerByManufacturerId(manufacturerId);
        mmap.put("baseManufacturer", baseManufacturer);
        return prefix + "/edit";
    }

    /**
     * 修改保存轮挡厂家管理
     */
    @RequiresPermissions("manage:base_manufacturer:edit")
    @Log(title = "轮挡厂家管理", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(BaseManufacturer baseManufacturer)
    {
        return toAjax(baseManufacturerService.updateBaseManufacturer(baseManufacturer));
    }

    /**
     * 删除轮挡厂家管理
     */
    @RequiresPermissions("manage:base_manufacturer:remove")
    @Log(title = "轮挡厂家管理", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(baseManufacturerService.deleteBaseManufacturerByManufacturerIds(ids));
    }
}
