package com.ruoyi.manage.controller;

import java.util.List;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.ModelMap;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.manage.domain.RecordIn;
import com.ruoyi.manage.service.IRecordInService;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 轮挡入库记录Controller
 * 
 * @author wangh
 * @date 2024-01-17
 */
@Controller
@RequestMapping("/manage/record_in")
public class RecordInController extends BaseController
{
    private String prefix = "manage/record_in";

    @Autowired
    private IRecordInService recordInService;

    @RequiresPermissions("manage:record_in:view")
    @GetMapping()
    public String record_in()
    {
        return prefix + "/record_in";
    }

    /**
     * 查询轮挡入库记录列表
     */
    @RequiresPermissions("manage:record_in:list")
    @PostMapping("/list")
    @ResponseBody
    public TableDataInfo list(RecordIn recordIn)
    {
        startPage();
        List<RecordIn> list = recordInService.selectRecordInList(recordIn);
        return getDataTable(list);
    }

    /**
     * 导出轮挡入库记录列表
     */
    @RequiresPermissions("manage:record_in:export")
    @Log(title = "轮挡入库记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    @ResponseBody
    public AjaxResult export(RecordIn recordIn)
    {
        List<RecordIn> list = recordInService.selectRecordInList(recordIn);
        ExcelUtil<RecordIn> util = new ExcelUtil<RecordIn>(RecordIn.class);
        return util.exportExcel(list, "轮挡入库记录数据");
    }

    /**
     * 新增轮挡入库记录
     */
    @GetMapping("/add")
    public String add()
    {
        return prefix + "/add";
    }

    /**
     * 新增保存轮挡入库记录
     */
    @RequiresPermissions("manage:record_in:add")
    @Log(title = "轮挡入库记录", businessType = BusinessType.INSERT)
    @PostMapping("/add")
    @ResponseBody
    public AjaxResult addSave(RecordIn recordIn)
    {
        return toAjax(recordInService.insertRecordIn(recordIn));
    }

    /**
     * 修改轮挡入库记录
     */
    @RequiresPermissions("manage:record_in:edit")
    @GetMapping("/edit/{objid}")
    public String edit(@PathVariable("objid") Long objid, ModelMap mmap)
    {
        RecordIn recordIn = recordInService.selectRecordInByObjid(objid);
        mmap.put("recordIn", recordIn);
        return prefix + "/edit";
    }

    /**
     * 修改保存轮挡入库记录
     */
    @RequiresPermissions("manage:record_in:edit")
    @Log(title = "轮挡入库记录", businessType = BusinessType.UPDATE)
    @PostMapping("/edit")
    @ResponseBody
    public AjaxResult editSave(RecordIn recordIn)
    {
        return toAjax(recordInService.updateRecordIn(recordIn));
    }

    /**
     * 删除轮挡入库记录
     */
    @RequiresPermissions("manage:record_in:remove")
    @Log(title = "轮挡入库记录", businessType = BusinessType.DELETE)
    @PostMapping( "/remove")
    @ResponseBody
    public AjaxResult remove(String ids)
    {
        return toAjax(recordInService.deleteRecordInByObjids(ids));
    }
}
